AC_DEFUN([NORDUGRID_INIT],
[

AC_REQUIRE([ARC_PREPARE_PREFIX])
AC_MSG_CHECKING([for SYSV init scripts])
AC_ARG_WITH(sysv-scripts-location,
  [  --with-sysv-scripts-location=<PATH>  Location of the SYSV init scripts. [[autodetect]]],
  [ initddir="$withval" ],
  [
    initddir=
    for i in init.d rc.d/init.d; do
      if test -d "/etc/$i" -a ! -h "/etc/$i" ; then
	initddir="$sysconfdir/$i"
	break
      fi
    done
    if test -z "$initddir"; then
      AC_MSG_ERROR(could not find a suitable location for the SYSV init scripts)
    fi
  ]
)
AC_MSG_RESULT($initddir)
AC_SUBST(initddir)

AC_ARG_WITH(monitor-prefix,
  [  --with-monitor-prefix=<PATH>         Specify the location of the Grid Monitor WWW scripts. [[LOCALSTATEDIR/www/html/gridmonitor]]],
  [ monitor_prefix="$withval" ],
  [ monitor_prefix="$localstatedir/www/html/gridmonitor" ]
)
AC_SUBST(monitor_prefix)

AC_ARG_WITH(monitor-local-prefix,
  [  --with-monitor-local-prefix=<PATH>   Specify the relative location of the Grid Monitor WWW scripts [[gridmonitor]]],
  [ monitor_local_prefix="$withval" ],
  [ monitor_local_prefix=`basename $monitor_prefix` ]
)
AC_SUBST(monitor_local_prefix)

default_cronddir="$sysconfdir/cron.d"
AC_ARG_WITH(cron-scripts-prefix,
  [  --with-cron-scripts-prefix=<PATH>    Specify the location of the cron directory. [[SYSCONFDIR/cron.d]]],
  [ cronddir="$withval" ],
  [ cronddir="$default_cronddir" ]
)
AC_SUBST(cronddir)

default_profiledir="$sysconfdir/profile.d"
AC_ARG_WITH(profile-scripts-prefix,
  [  --with-profile-scripts-prefix=<PATH> Specify the location of the profile directory. [[SYSCONFDIR/profile.d]]],
  [ profiledir="$withval" ],
  [ profiledir="$default_profiledir" ]
)
AC_SUBST(profiledir)

dnl
dnl Useful C/C++ compiler flags
dnl
CC_MISC_FLAGS=

dnl
dnl Try to use -ansi switch to force people write ASNI code
dnl
if test "x$CC" = "xgcc"; then
  CC_MISC_FLAGS="$CC_MISC_FLAGS -ansi"
fi
AC_SUBST(CC_MISC_FLAGS)

dnl
dnl Check for the pthread library
dnl
AC_CHECK_LIB([pthread], [pthread_mutex_init],
AC_TRY_COMPILE(
[#include <pthread.h>],
[#ifndef pthread_yield
  char *p = (char *) pthread_yield;
#endif
],AC_DEFINE(HAVE_PTHREAD_YIELD,,[Is pthread_yield declared])
)
)

AH_VERBATIM([NOT_HAVE_PTHREAD_YIELD],
#ifndef HAVE_PTHREAD_YIELD
#define pthread_yield sched_yield
#endif
)dnl


dnl
dnl gSOAP
dnl
gsoap=yes
https_init_script=""
AC_ARG_WITH(gsoap-location,
  [  --with-gsoap-location=<PATH>         Specify the gSOAP installation path. [[autodetect]]],
  [ AC_PATH_PROG(soapcpp2, soapcpp2, not found, $with_gsoap_location/bin) ],
  [ AC_PATH_PROG(soapcpp2, soapcpp2, not found) ]
)
if test "x$soapcpp2" = "xnot found"; then
  gsoap_location=""
  gsoap=
  SOAPCPP2=:
  WSDL2H=:
else
  gsoap_location=`echo "$soapcpp2" | sed -e 's%/bin/soapcpp2$%%' -e 't' -e 's%.*%%'`
  SOAPCPP2=$gsoap_location/bin/soapcpp2
  WSDL2H=$gsoap_location/bin/wsdl2h
  if test "x$gsoap_location" = "x/usr"; then
    :
  else
    GSOAP_INCLUDES=-I$gsoap_location/include
    AC_SUBST(GSOAP_INCLUDES)
  fi
dnl
dnl Find gSoap library
dnl Ps: we should really use pkgconfig: PKG_CHECK_MODULES(GSOAP, gsoap++ >= 2.7.2)
dnl
  for lib in lib64 lib
  do
    if test -f "$gsoap_location/$lib/libgsoap++.la"
    then
      GSOAP_LIBS="-L$gsoap_location/$lib -lgsoap++"
      break
    fi
    if test -f "$gsoap_location/$lib/libgsoap++.a"
    then
      GSOAP_LIBS="-L$gsoap_location/$lib -lgsoap++"
      break
    fi
    if test -f "$gsoap_location/$lib/libgsoap++.so"
    then
      GSOAP_LIBS="-L$gsoap_location/$lib -lgsoap++"
      break
    fi
  done
  if test x"$GSOAP_LIBS" = x ; then
    AC_MSG_WARN([No gSOAP library found. Please install gSOAP.])
    gsoap=
  fi
  https_init_script=httpsd

dnl
dnl gSOAP version
dnl
AC_MSG_CHECKING(for gSOAP version)
gsoap_version=`$gsoap_location/bin/soapcpp2 -v 2>&1 | sed -e 's/.*version \([[^ ]]*\).*/\1/' -e 't new' -e 's/^.*Compiler for C and C++ *\([[^ ]]*\).*/\1/' -e 't matched' -e 's/.*//' -e ':matched' -e ':new' | grep '.'`
if test "x$gsoap_version" = "x"; then
  AC_MSG_WARN([Could not determine version.])
  gsoap=
fi
gsoap_version_major=`echo "$gsoap_version" | sed -e 's/^\([[^\.]]\).*/\1/' -e 't match' -e 's/.*/0/' -e ':match'`
gsoap_version_minor=`echo "$gsoap_version" | sed -e 's/^[[^\.]]*\.\([[^\.]]*\).*/\1/' -e 't match' -e 's/.*/0/' -e ':match'`
gsoap_version_subminor=`echo "$gsoap_version" | sed -e 's/^[[^\.]]*\.[[^\.]]*\.\([[0-9]]*\).*/\1/' -e 't match' -e 's/.*/0/' -e ':match'`
OLD_GSOAP=
AC_MSG_RESULT($gsoap_version_major.$gsoap_version_minor.$gsoap_version_subminor)
if test "$gsoap_version_major" -lt "2"; then
  AC_MSG_WARN([found gSOAP version $gsoap_version_major.$gsoap_version_minor.$gsoap_version_subminor - gSOAP with version below 2.7.2 is not supported anymore])
  gsoap=
fi
if test "$gsoap_version_major" -eq "2"; then
  if test "$gsoap_version_minor" -lt "7" ; then
    AC_MSG_WARN([found gSOAP version $gsoap_version_major.$gsoap_version_minor.$gsoap_version_subminor - gSOAP with version below 2.7.2 is not supported anymore])
    gsoap=
  fi
  if test "$gsoap_version_minor" -eq "7" && test "$gsoap_version_subminor" -lt "2" ; then
    AC_MSG_WARN([found gSOAP version $gsoap_version_major.$gsoap_version_minor.$gsoap_version_subminor - gSOAP with version below 2.7.2 is not supported anymore])
    gsoap=
  fi
fi

cat > gsoaptest.xsd <<EOF
<?xml version="1.0" encoding="UTF-8"?>
<xsd:schema xmlns:xsd="http://www.w3.org/2001/XMLSchema" elementFormDefault="qualified">
	<xsd:complexType name="X">
		<xsd:sequence>
			<xsd:element ref="Y"/>
		</xsd:sequence>
	</xsd:complexType>
	<xsd:element name="Y" type="xsd:string"/>
</xsd:schema>
EOF

${WSDL2H} -s gsoaptest.xsd

${SOAPCPP2} -p gsoaptest gsoaptest.h

AC_LANG_SAVE
AC_LANG_CPLUSPLUS
CXXFLAGS_SAVE=$CXXFLAGS
CXXFLAGS="$CXXFLAGS $GSOAP_INCLUDES"
AC_TRY_COMPILE([#include "gsoaptestStub.h"],
    [ns1__X x; x.Y = "";],
    [use_namespaces="no"],
    [AC_TRY_COMPILE([#include "gsoaptestStub.h"],
	[ns1__X x; x.ns1__Y = "";],
	[use_namespaces="yes"],
	[gsoap=])
    ]
)

CXXFLAGS=$CXXFLAGS_SAVE
AC_LANG_RESTORE

rm -rf gsoaptest*

if test "x$use_namespaces" = "xyes"; then
  AC_DEFINE(GSOAP_ALWAYS_USES_NAMESPACES_FOR_MEMBER_NAMES,,[define if gSOAP prepends names of class members with namespace])
fi

fi

if test "$gsoap" == "yes"; then
  :
else
  AC_MSG_WARN([gSoap not found - many things will not be built])
fi

AC_SUBST(https_init_script)
AC_SUBST(SOAPCPP2)
AC_SUBST(WSDL2H)
AC_SUBST(GSOAP_LIBS)
AC_SUBST(GSOAP_LOCATION,$gsoap_location)
AM_CONDITIONAL(HAVE_GSOAP, test "x$gsoap" = "xyes")

dnl AC_PYTHON_DEVEL
#
# Python check - only need to have the python binary in the path and
# standard python directory layout
#

dnl
dnl Enable Python wrappers
dnl
PYTHON_LOCATION= 
PYTHON_INCLUDES=
python_devel=no
AC_ARG_ENABLE(python_wrappers,
  [  --disable-python-wrappers          Disable Python wrappers for ARCLIB],  
  [
    case "${enableval}" in
      yes) python_wrappers=true ;;
      no)  python_wrappers=false; AC_MSG_WARN(Python wrappers will be disabled) ;;
      *)   AC_MSG_ERROR(bad value ${enableval} for --disable-python-wrappers) ;;
    esac
  ],
  [ python_wrappers=true ]
)

if test "x$python_wrappers" = xtrue ; then

AM_PATH_PYTHON(2.0)
if test -n "$PYTHON"; then
  # Strip 2 path components to find PYTHON location
  PYTHON_LOCATION=`dirname $PYTHON`
  PYTHON_LOCATION=`dirname $PYTHON_LOCATION`
  AC_CHECK_HEADERS($PYTHON_LOCATION/include/python$PYTHON_VERSION/Python.h,
                 [python_devel=yes
                  PYTHON_INCLUDES=-I$PYTHON_LOCATION/include/python$PYTHON_VERSION
                 ],
                 [python_devel=no
                  AC_MSG_WARN([No python headers found - disabling arclib python bindings])])
else
  PYTHON_LOCATION=
fi

fi
AC_SUBST([PYTHON_INCLUDES],[$PYTHON_INCLUDES])
AC_SUBST([PYTHONLIB],[`echo $pythondir|cut -f2- -d/`])
AM_CONDITIONAL(HAVE_PYTHON_DEVEL, test x$python_devel = xyes)

AC_ARG_WITH(mysql-location,
  [  --with-mysql-location=<PATH>         Specify the MySQL installation path. [[autodetect]]],
  [ AC_PATH_PROG(mysql_config, mysql_config, not found, $with_mysql_location/bin) ],
  [ AC_PATH_PROG(mysql_config, mysql_config, not found) ]
)
MYSQL_INCLUDES=
MYSQL_LIBS=
if test "x$mysql_config" != "xnot found"; then
  AC_MSG_CHECKING(for mysql includes)
  mysql_include=`$mysql_config --cflags | sed "s/^-I\([[^ ]]*\).*/\1\/mysql.h/;s/'//g"`
  if ! test -f "$mysql_include"; then
    AC_MSG_RESULT(not found)
    mysql_config=""
  else
    AC_MSG_RESULT(found)
    MYSQL_INCLUDES=`$mysql_config --cflags | sed "s/'//g"`
    MYSQL_LIBS=`$mysql_config --libs | sed "s/'//g"`
  fi
else
  mysql_config=""
fi
AC_SUBST(MYSQL_INCLUDES)
AC_SUBST(MYSQL_LIBS)

XML_LIBS=
AC_ARG_WITH(xml-location,
  [  --with-libxml-location=<PATH>        Specify the libxml2 installation path. [[autodetect]]],
  [ AC_PATH_PROG(xml_config, xml2-config, not found, $with_libxml_location/bin) ],
  [ AC_PATH_PROG(xml_config, xml2-config, not found) ]
)
if test "x$xml_config" != "xnot found"; then
  XML_INCLUDES=`$xml_config --cflags`
  # Remove /usr/include
  XML_INCLUDES=`echo $XML_INCLUDES | sed -e 's, *-I/usr/include/*$, ,g' -e 's, *-I/usr/include/* , ,g'`
  XML_LIBS=`$xml_config --libs`
fi
AC_SUBST(XML_INCLUDES)
AC_SUBST(XML_LIBS)
AM_CONDITIONAL(HAVE_LIBXML, test "x$xml_config" != "xnot found")

dnl
dnl GACL_LOCATION
dnl
gridsite=yes
DEFAULT_GRIDSITE_LOCATION=/opt/gridsite
AC_SUBST(DEFAULT_GRIDSITE_LOCATION)
AC_MSG_CHECKING(for GACL)
AC_ARG_WITH(gacl-location,
  [  --with-gacl-location=<PATH>          Specify the GACL installation path. [[/opt/gridsite|autodetect]]],
  [ GACL_LOCATION=$with_gacl_location ],
  [
    if test "x$GACL_LOCATION" = "x"; then
      GACL_LOCATION=$DEFAULT_GRIDSITE_LOCATION
    fi
  ]
)
if test ! -d $GACL_LOCATION; then
  GACL_LOCATION="$PWD/grid-manager/external/gacl-0.1.5"
  gridsite=
else
  if test ! -f $GACL_LOCATION/lib/libgridsite.a; then
    GACL_LOCATION="$PWD/grid-manager/external/gacl-0.1.5"
    gridsite=
  fi
fi
AC_MSG_RESULT($GACL_LOCATION)  
AC_SUBST(GACL_LOCATION)
AM_CONDITIONAL(NG_GACL, test "x$gridsite" = "x")
AM_CONDITIONAL(GRIDSITE_GACL, test "x$gridsite" != "x")
if test "x$gridsite" = "x"; then
  AC_DEFINE(NG_GACL,,[GACL patched by NG])
else
  AC_DEFINE(GRIDSITE_GACL,,[Gridsite GACL (also patched by NG)])
fi

dnl
dnl 
dnl
AC_ARG_ENABLE(pkgdirs,
  [  --enable-pkgdirs                  Use pkg directories. Useful for /usr installations.],  
  [
    case "${enableval}" in
      yes) pkgdirs=yes ; AC_MSG_WARN(pkg directories will be enabled) ;;
      no)  pkgdirs=no ;;
      *)   AC_MSG_ERROR(bad value ${enableval} for --disable-pkgdirs) ;;
    esac
  ],
  [ pkgdirs=no ]
)

if test "x$pkgdirs" = "xyes"; then
  pkglibdir="${libdir}/${PACKAGE}"
  pkglibexecdir="${libexecdir}/${PACKAGE}"
  pkgdatadir="${datadir}/${PACKAGE}"
  docdir="${datadir}/doc/${PACKAGE}"
else
  pkglibdir="${libdir}"
  pkglibexecdir="${libexecdir}"
  pkgdatadir="${datadir}"
  docdir="${datadir}/doc"
fi
# older autoconf do not know some of these variables
AC_SUBST([pkglibdir])
AC_SUBST([pkglibexecdir])
AC_SUBST([pkgdatadir])
AC_SUBST([docdir])

dnl
dnl NORDUGRID_LOCATION
dnl
AC_ARG_WITH(nordugrid-location,
  [  --with-nordugrid-location=<PATH>     OBSOLETE Specify the nordugrid installation path. [[/usr]]],
  AC_MSG_ERROR([Option --with-nordugrid-location has been obsoleted please use --prefix and --disable-pkgdirs to get the same sresult])
)
ARC_WITH_FINAL_PREFIX([
  AC_DEFINE_UNQUOTED(DEFAULT_ARC_LOCATION,"$exec_prefix",[Default NorduGrid installation path])
  AC_DEFINE_UNQUOTED(DEFAULT_NORDUGRID_LOCATION,"$exec_prefix",[Default NorduGrid installation path])
  AC_SUBST(nordugrid_location, "$exec_prefix")
])

# globus/gpt packages
PKG_CHECK_MODULES(GLOBUS_COMMON, [globus-common], [
GLOBUS_COMMON_VERSION=`$PKG_CONFIG --modversion globus-common`], [
GPT_PKG(globus_common)
])
AC_SUBST(GLOBUS_COMMON)
AC_SUBST(GLOBUS_COMMON)

PKG_CHECK_MODULES(GLOBUS_RLS_CLIENT, [globus-rls-client], [
GLOBUS_RLS_CLIENT_VERSION=`$PKG_CONFIG --modversion globus-rls-client`], [
GPT_PKG(globus_rls_client)
])
AC_SUBST(GLOBUS_RLS_CLIENT_CFLAGS)
AC_SUBST(GLOBUS_RLS_CLIENT_LIBS)

PKG_CHECK_MODULES(GLOBUS_GSSAPI_GSI, [globus-gssapi-gsi], [
GLOBUS_GSSAPI_VERSION=`$PKG_CONFIG --modversion globus-gssapi-gsi`], [
GPT_PKG(globus_gssapi_gsi)
])
AC_SUBST(GLOBUS_GSSAPI_GSI_CFLAGS)
AC_SUBST(GLOBUS_GSSAPI_GSI_LIBS)

PKG_CHECK_MODULES(GLOBUS_FTP_CLIENT, [globus-ftp-client], [
GLOBUS_FTP_CLIENT_VERSION=`$PKG_CONFIG --modversion globus-ftp-client`], [
GPT_PKG(globus_ftp_client)
])
AC_SUBST(GLOBUS_FTP_CLIENT_CFLAGS)
AC_SUBST(GLOBUS_FTP_CLIENT_LIBS)

PKG_CHECK_MODULES(GLOBUS_FTP_CONTROL, [globus-ftp-control], [
GLOBUS_FTP_CONTROL_VERSION=`$PKG_CONFIG --modversion globus-ftp-control`], [
GPT_PKG(globus_ftp_control)
])
AC_SUBST(GLOBUS_FTP_CONTROL_CFLAGS)
AC_SUBST(GLOBUS_FTP_CONTROL_LIBS)

PKG_CHECK_MODULES(GLOBUS_RSL, [globus-rsl], [
GLOBUS_RSL_VERSION=`$PKG_CONFIG --modversion globus-rsl`], [
GPT_PKG(globus_rsl)
])
AC_SUBST(GLOBUS_RSL_CFLAGS)
AC_SUBST(GLOBUS_RSL_LIBS)

PKG_CHECK_MODULES(GLOBUS_IO, [globus-io], [
GLOBUS_IO_VERSION=`$PKG_CONFIG --modversion globus-io`], [
GPT_PKG(globus_io)
])
AC_SUBST(GLOBUS_IO_CFLAGS)
AC_SUBST(GLOBUS_IO_LIBS)

PKG_CHECK_MODULES(GLOBUS_GSI_PROXY_CORE, [globus-gsi-proxy-core], [
GLOBUS_GSI_PROXY_CORE_VERSION=`$PKG_CONFIG --modversion globus-gsi-proxy-core`], [
GPT_PKG(globus_gsi_proxy_core)
])
AC_SUBST(GLOBUS_GSI_PROXY_CORE_CFLAGS)
AC_SUBST(GLOBUS_GSI_PROXY_CORE_LIBS)

PKG_CHECK_MODULES(GLOBUS_GSS_ASSIST, [globus-gss-assist], [
GLOBUS_GSS_ASSIST_VERSION=`$PKG_CONFIG --modversion globus-gss-assist`], [
GPT_PKG(globus_gss_assist)
])
AC_SUBST(GLOBUS_GSS_ASSIST_CFLAGS)
AC_SUBST(GLOBUS_GSS_ASSIST_LIBS)

PKG_CHECK_MODULES(MYPROXY, [myproxy], [
MYPROXY_VERSION=`$PKG_CONFIG --modversion myproxy`], [
GPT_PKG(myproxy)
])
AC_SUBST(MYPROXY_CFLAGS)
AC_SUBST(MYPROXY_LIBS)

PKG_CHECK_MODULES(GLOBUS_OPENSSL, [globus-openssl], [
GLOBUS_OPENSSL_VERSION=`$PKG_CONFIG --modversion globus-openssl`], [
GPT_PKG(globus_openssl)
])
AC_SUBST(GLOBUS_OPENSSL)
AC_SUBST(GLOBUS_OPENSSL)

GLOBUS_INCLUDES="$GLOBUS_COMMON_CFLAGS $GLOBUS_OPENSSL_CFLAGS"
AC_SUBST(GLOBUS_INCLUDES)

# Check for gridftp-v2
SAVE_CFLAGS=$CFLAGS
SAVE_LIBS=$LIBS
CFLAGS="$CFLAGS $GLOBUS_FTP_CLIENT_CFLAGS"
LIBS="$LIBS $GLOBUS_FTP_CLIENT_LIBS"
AC_CHECK_FUNCS(globus_ftp_client_handleattr_set_gridftp2)
CFLAGS=$SAVE_CFLAGS
LIBS=$SAVE_LIBS

SAVE_CPPFLAGS=$CPPFLAGS
CPPFLAGS="$CPPFLAGS $GLOBUS_INCLUDES $MYPROXY_CFLAGS"
AC_CHECK_HEADERS([globus_gsi_proxy.h])
AC_CHECK_HEADERS([globus_rls_client.h],[rls_supported=yes],[rls_supported=no])
AC_CHECK_HEADERS([myproxy.h],myproxy_supported=yes,myproxy_supported=no)
AC_CHECK_HEADERS([sasl.h],sasl_supported=yes,sasl_supported=no)
AC_CHECK_HEADERS([sasl/sasl.h],sasl_supported=yes,sasl_supported=no)
CPPFLAGS=$SAVE_CPPFLAGS

if test "x$GLOBUS_IO_VERSION" = "x"; then
  IO_VERSION_MAJOR=0
else
  IO_VERSION_MAJOR=`echo "$GLOBUS_IO_VERSION" | sed 's/^\([[^.]]\).*/\1/'`;
fi
AC_DEFINE_UNQUOTED(GLOBUS_IO_VERSION,$IO_VERSION_MAJOR,[Globus IO version])

# Check for the globus_gss_assist_authorization_host_name function
SAVE_CFLAGS=$CFLAGS
SAVE_LIBS=$LIBS
CFLAGS="$CFLAGS $GLOBUS_GSS_ASSIST_CFLAGS"
LIBS="$LIBS $GLOBUS_GSS_ASSIST_LIBS"
AC_CHECK_FUNCS(globus_gss_assist_authorization_host_name)
CFLAGS=$SAVE_CFLAGS
LIBS=$SAVE_LIBS

dnl
dnl DEFAULT_GLOBUS_LOCATION
dnl
AC_MSG_CHECKING(for DEFAULT_GLOBUS_LOCATION)
AC_ARG_WITH(default-globus-location,
  [  --with-default-globus-location=<PATH>  Specify the default globus location. [[autodetect]]],
  [
    DEFAULT_GLOBUS_LOCATION="$withval"
  ],
  [
    DEFAULT_GLOBUS_LOCATION="${GLOBUS_LOCATION:-/usr}"
  ]
)
AC_MSG_RESULT($DEFAULT_GLOBUS_LOCATION)  
AC_DEFINE_UNQUOTED(DEFAULT_GLOBUS_LOCATION,"$DEFAULT_GLOBUS_LOCATION",[Default Globus installation path])
AC_SUBST(DEFAULT_GLOBUS_LOCATION)

dnl
dnl Choose OpenLDAP package to use
dnl
AC_ARG_ENABLE(globus_openldap,
  [  --enable-globus-openldap          Use OpenLDAP provided as part of Globus],  
  [
    case "${enableval}" in
      yes)
	globus_openldap=yes
	AC_MSG_NOTICE(globus openldap was enabled)
	;;
      no)
	globus_openldap=no
	AC_MSG_NOTICE(globus openldap was disabled)
	;;
      *)
	AC_MSG_ERROR(bad value ${enableval} for --enable-globus-openldap)
	;;
    esac
  ],
  [ globus_openldap= ]
)

dnl
dnl Autodetect suitable OpenLDAP if user not specified
dnl
if test "x$globus_openldap" = "x"; then
  AC_MSG_CHECKING(if Globus uses own OpenSSL)
  if test -f "${GLOBUS_LOCATION:-/usr}/lib/libglobus_ftp_client.so" -o \
          -f "${GLOBUS_LOCATION:-/usr}/lib64/libglobus_ftp_client.so"; then
    if test "x$LIBLDAP" = "x"; then
      AC_MSG_ERROR(no - need independent OpenLDAP - please install)
    else
      AC_MSG_RESULT(no - will use previously detected OpenLDAP)
    fi
  elif test -f "${GLOBUS_LOCATION:-/usr}/lib/libglobus_ftp_client_$GPT_FLAVOR.so"; then
    ldd "${GLOBUS_LOCATION:-/usr}/lib/libglobus_ftp_client_$GPT_FLAVOR.so" 2>/dev/null | grep "libssl_$GPT_FLAVOR" 2>/dev/null 1>/dev/null
    if test $? = 0; then
      AC_MSG_RESULT(yes - must use Globus OpenLDAP)
      globus_openldap=yes
    else
      if test "x$LIBLDAP" = "x"; then
        AC_MSG_ERROR(no - need independent OpenLDAP - please install)
      else
        AC_MSG_RESULT(no - will use previously detected OpenLDAP)
      fi
    fi
  else
    AC_MSG_ERROR(can't check - install Globus FTP Client library of flavor $GPT_FLAVOR or specify which OpenLDAP to use explicitely)
  fi
fi

dnl
dnl Check for Globus OpenLDAP 
dnl
if test "x$globus_openldap" = "xyes"; then
  SAVE_LDFLAGS=$LDFLAGS
  LDFLAGS="-L${GLOBUS_LOCATION:-/usr}/lib -llber_$GPT_FLAVOR -lpthread"
  AC_CHECK_LIB([ldap_r_$GPT_FLAVOR], [ldap_first_message], [ LIBLDAP="-L${GLOBUS_LOCATION:-/usr}/lib -lldap_r_$GPT_FLAVOR -llber_$GPT_FLAVOR" ], [
    AC_CHECK_LIB([ldap_$GPT_FLAVOR], [ldap_first_message], [ LIBLDAP="-L${GLOBUS_LOCATION:-/usr}/lib -lldap_$GPT_FLAVOR -llber_$GPT_FLAVOR" ], [
      AC_MSG_ERROR(Missing OpenLDAP libraries of flavor $GPT_FLAVOR in Globus installation)
    ])
  ])
  AC_SUBST(LIBLDAP)
  LDFLAGS=$SAVE_LDFLAGS
fi

dnl
dnl Enable VOMS
dnl
voms=true
ng_voms=
edg_voms=
AC_ARG_ENABLE(voms,
  [  --disable-voms                     Disable VOMS support],  
  [
    case "${enableval}" in
      yes) voms=true ;;
      no)  voms=false; AC_MSG_WARN(VOMS will be disabled) ;;
      *)   AC_MSG_ERROR(bad value ${enableval} for --disable-voms) ;;
    esac
  ],
  [ voms=true ]
)

if test "x$voms" = xtrue ; then

dnl
dnl VOMS_LOCATION
dnl
DEFAULT_VOMS_LOCATION=/usr
AC_SUBST(DEFAULT_VOMS_LOCATION)
AC_ARG_WITH(voms-location,
  [  --with-voms-location=<PATH>          Specify the VOMS installation path. [[/usr]]],
  [ 
    VOMS_LOCATION=$with_voms_location
    if test ! -d $VOMS_LOCATION; then
      AC_MSG_WARN([VOMS_LOCATION ($VOMS_LOCATION) does not exist])
      VOMS_LOCATION=
    fi
  ],[
    if test "x$VOMS_LOCATION" = "x"; then
      VOMS_LOCATION=$DEFAULT_VOMS_LOCATION
    fi
    if test ! -d $VOMS_LOCATION; then
      VOMS_LOCATION=
    fi
  ]
)

dnl
dnl Check for VOMS api availability and type
dnl
VOMS_INCLUDES=""
if test -d /usr/include/voms; then
  VOMS_INCLUDES="-I/usr/include/voms"
fi
if test "x$VOMS_LOCATION" != "x"; then
  if test -d "$VOMS_LOCATION/include/voms"; then
    VOMS_INCLUDES="-I$VOMS_LOCATION/include/voms"
  else
    VOMS_INCLUDES="-I$VOMS_LOCATION/include/glite/security/voms"
  fi
  if test "$VOMS_LOCATION" != "/usr"; then
    VOMS_INCLUDES="$VOMS_INCLUDES -I$VOMS_LOCATION/include"
  fi
fi
AC_SUBST(VOMS_INCLUDES)

VOMS_LIBS=
SAVE_CPPFLAGS=$CPPFLAGS
CPPFLAGS="$VOMS_INCLUDES $GLOBUS_GSS_ASSIST_CFLAGS"
AC_LANG(C++)
AC_CHECK_HEADERS([voms_api.h],
  [AC_CHECK_HEADERS([api_util.h],
    ng_voms=true,
    edg_voms=true
  )]
  VOMS_LDFLAGS=$GLOBUS_GSS_ASSIST_LIBS
  if test "x$VOMS_LOCATION" != "x"; then
    VOMS_LDFLAGS="$VOMS_LDFLAGS -L$VOMS_LOCATION/lib64 -L$VOMS_LOCATION/lib"
  fi
  SAVE_LDFLAGS=$LDFLAGS
  LDFLAGS="$LDFLAGS $VOMS_LDFLAGS"
  AC_CHECK_LIB(vomsapi, VOMS_Init,
    VOMS_LIBS="$VOMS_LDFLAGS -lvomsapi",
  AC_CHECK_LIB(vomsapi_$GPT_FLAVOR, VOMS_Init,
    VOMS_LIBS="$VOMS_LDFLAGS -lvomsapi_$GPT_FLAVOR", voms=false,) ,)
  LDFLAGS=$SAVE_LDFLAGS
  ,
  voms=false
)
CPPFLAGS=$SAVE_CPPFLAGS
AC_SUBST(VOMS_LIBS)
AC_LANG(C)

fi

if test "x$voms" != xtrue ; then
  ng_voms=
  edg_voms=
  AC_MSG_WARN(VOMS will be disabled)
  voms_supported="no"
fi

if test "x$ng_voms" != "x" ; then
  AC_DEFINE(NG_VOMS,,[voms-1.1.x])
  voms_supported="old NG patched"
fi
if test "x$edg_voms" != "x" ; then
  AC_DEFINE(EDG_VOMS,,[voms-1.2.x])
  voms_supported="yes"
fi
AM_CONDITIONAL(NG_VOMS, test "x$ng_voms" != "x")
AM_CONDITIONAL(EDG_VOMS, test "x$edg_voms" != "x")
AM_CONDITIONAL(SUPPORT_VOMS, test "x$voms" != "x")

dnl
dnl Enable LCAS
dnl
lcas=true
AC_ARG_ENABLE(lcas,
  [  --disable-lcas                     Disable LCAS support],  
  [
    case "${enableval}" in
      yes) lcas=true ;;
      no)  lcas=false; AC_MSG_WARN(LCAS will be disabled) ;;
      *)   AC_MSG_ERROR(bad value ${enableval} for --disable-lcas) ;;
    esac
  ],
  [ lcas=true ]
)

if test "x$lcas" = xtrue ; then

dnl
dnl LCAS_LOCATION
dnl
DEFAULT_LCAS_LOCATION=/opt/glite
LCAS_LOCATION=
AC_ARG_WITH(lcas-location,
  [  --with-lcas-location=<PATH>          Specify the LCAS installation path. [[/opt/glite]]],
  [ 
    LCAS_LOCATION=$with_lcas_location
    if test ! -d $LCAS_LOCATION; then
      AC_MSG_WARN([LCAS_LOCATION ($LCAS_LOCATION) does not exist])
      LCAS_LOCATION=
    fi
  ],[
    if test "x$LCAS_LOCATION" = "x"; then
      LCAS_LOCATION=$DEFAULT_LCAS_LOCATION
    fi
    if test ! -d $LCAS_LOCATION; then
      LCAS_LOCATION=
    fi
  ]
)

dnl
dnl Check for LCAS api availability
dnl
LCAS_INCLUDES=""
if test "x$LCAS_LOCATION" != "x"; then
  LCAS_INCLUDES=-I$LCAS_LOCATION/include
fi
AC_SUBST(LCAS_INCLUDES)

LCAS_LIBS=
SAVE_CPPFLAGS=$CPPFLAGS
CPPFLAGS="$LCAS_INCLUDES $GLOBUS_GSS_ASSIST_CFLAGS"
AC_CHECK_HEADERS([lcas.h],
  LCAS_LDFLAGS=
  if test "x$LCAS_LOCATION" != "x"; then
    if test -d $LCAS_LOCATION/lib64; then
      LCAS_LDFLAGS="-L$LCAS_LOCATION/lib64"
    else
      LCAS_LDFLAGS="-L$LCAS_LOCATION/lib"
    fi
  fi
  SAVE_LDFLAGS=$LDFLAGS
  LDFLAGS="$LDFLAGS $LCAS_LDFLAGS"
  AC_CHECK_LIB(lcas, lcas_init, LCAS_LIBS="$LCAS_LDFLAGS -llcas", lcas=false,)
  LDFLAGS=$SAVE_LDFLAGS
  ,
  lcas=false
)
CPPFLAGS=$SAVE_CPPFLAGS
AC_SUBST(LCAS_LIBS)

fi

if test "x$lcas" != xtrue ; then
  AC_MSG_WARN(LCAS will be disabled)
  lcas_supported="no"
else
  AC_DEFINE(HAVE_LCAS,,[gLite LCAS])
  lcas_supported="yes"
fi
 
AM_CONDITIONAL(HAVE_LCAS, test "x$lcas" = xtrue)


dnl
dnl Enable LCMAPS
dnl
lcmaps=true
AC_ARG_ENABLE(lcmaps,
  [  --disable-lcmaps                   Disable LCMAPS support],  
  [
    case "${enableval}" in
      yes) lcmaps=true ;;
      no)  lcmaps=false; AC_MSG_WARN(LCMAPS will be disabled) ;;
      *)   AC_MSG_ERROR(bad value ${enableval} for --disable-lcmaps) ;;
    esac
  ],
  [ lcmaps=true ]
)

if test "x$lcmaps" = xtrue ; then

dnl
dnl LCMAPS_LOCATION
dnl
DEFAULT_LCMAPS_LOCATION=/opt/glite
LCMAPS_LOCATION=
AC_ARG_WITH(lcmaps-location,
  [  --with-lcmaps-location=<PATH>        Specify the LCMAPS installation path. [[/opt/glite]]],
  [ 
    LCMAPS_LOCATION=$with_lcmaps_location
    if test ! -d $LCMAPS_LOCATION; then
      AC_MSG_WARN([LCMAPS_LOCATION ($LCMAPS_LOCATION) does not exist])
      LCMAPS_LOCATION=
    fi
  ],[
    if test "x$LCMAPS_LOCATION" = "x"; then
      LCMAPS_LOCATION=$DEFAULT_LCMAPS_LOCATION
    fi
    if test ! -d $LCMAPS_LOCATION; then
      LCMAPS_LOCATION=
    fi
  ]
)

dnl
dnl Check for LCMAPS api availability
dnl
LCMAPS_INCLUDES=""
if test "x$LCMAPS_LOCATION" != "x"; then
  LCMAPS_INCLUDES=-I$LCMAPS_LOCATION/include
fi
AC_SUBST(LCMAPS_INCLUDES)

LCMAPS_LIBS=
SAVE_CPPFLAGS=$CPPFLAGS
CPPFLAGS="$LCMAPS_INCLUDES $GLOBUS_GSS_ASSIST_CFLAGS"
AC_CHECK_HEADERS([lcmaps.h],
  LCMAPS_LDFLAGS=
  if test "x$LCMAPS_LOCATION" != "x"; then
    if test -d $LCMAPS_LOCATION/lib64; then
      LCMAPS_LDFLAGS="-L$LCMAPS_LOCATION/lib64"
    else
      LCMAPS_LDFLAGS="-L$LCMAPS_LOCATION/lib"
    fi
  fi
  SAVE_LDFLAGS=$LDFLAGS
  LDFLAGS="$LDFLAGS $LCMAPS_LDFLAGS"
  AC_CHECK_LIB(lcmaps,lcmaps_init, LCMAPS_LIBS="$LCMAPS_LDFLAGS -llcmaps",lcmaps=false,)
  LDFLAGS=$SAVE_LDFLAGS
  ,
  lcmaps=false
)
CPPFLAGS=$SAVE_CPPFLAGS
AC_SUBST(LCMAPS_LIBS)

fi

if test "x$lcmaps" != xtrue ; then
  AC_MSG_WARN(LCMAPS will be disabled)
  lcmaps_supported="no"
else
  AC_DEFINE(HAVE_LCMAPS,,[gLite LCMAPS])
  lcmaps_supported="yes"
fi
 
AM_CONDITIONAL(HAVE_LCMAPS, test "x$lcmaps" = xtrue)

dnl
dnl Enable LFC
dnl
lfc=true
AC_ARG_ENABLE(lfc,
  [  --disable-lfc                      Disable LFC support],  
  [
    case "${enableval}" in
      yes) lfc=true ;;
      no)  lfc=false; AC_MSG_WARN(LFC will be disabled) ;;
      *)   AC_MSG_ERROR(bad value ${enableval} for --disable-lfc) ;;
    esac
  ],
  [ lfc=true ]
)

if test "x$lfc" = xtrue ; then

dnl
dnl LFC_LOCATION
dnl
DEFAULT_LFC_LOCATION=/opt/glite
LFC_LOCATION=
AC_ARG_WITH(lfc-location,
  [  --with-lfc-location=<PATH>           Specify the LFC installation path. [[/opt/glite]]],
  [ 
    LFC_LOCATION=$with_lfc_location
    if test ! -d $LFC_LOCATION; then
      AC_MSG_WARN([LFC_LOCATION ($LFC_LOCATION) does not exist])
      LFC_LOCATION=
    fi
  ],[
    if test "x$LFC_LOCATION" = "x"; then
      LFC_LOCATION=$DEFAULT_LFC_LOCATION
    fi
    if test ! -d $LFC_LOCATION; then
      LFC_LOCATION=
    fi
  ]
)

dnl
dnl Check for LFC api availability
dnl
LFC_INCLUDES=""
if test -d /usr/include/lfc; then
  LFC_INCLUDES="-I/usr/include/lfc"
fi
if test "x$LFC_LOCATION" != "x"; then
  LFC_INCLUDES=-I$LFC_LOCATION/include/lfc
fi
AC_SUBST(LFC_INCLUDES)

LFC_LIBS=
SAVE_CPPFLAGS=$CPPFLAGS
CPPFLAGS="$LFC_INCLUDES"
AC_CHECK_HEADERS([lfc_api.h],
  LFC_LDFLAGS="-ldl -lpthread"
  if test "x$LFC_LOCATION" != "x"; then
    if test -d $LFC_LOCATION/lib64; then
      LFC_LDFLAGS="-L$LFC_LOCATION/lib64 -ldl -lpthread"
    else
      LFC_LDFLAGS="-L$LFC_LOCATION/lib -ldl -lpthread"
    fi

  fi
  SAVE_LDFLAGS=$LDFLAGS
  LDFLAGS="$LDFLAGS $LFC_LDFLAGS"
  AC_CHECK_LIB(lfc,lfc_startsess, LFC_LIBS="$LFC_LDFLAGS -llfc",lfc=false,)
  LDFLAGS=$SAVE_LDFLAGS
  ,
  lfc=false
)
CPPFLAGS=$SAVE_CPPFLAGS
AC_SUBST(LFC_LIBS)

fi

if test "x$lfc" != xtrue ; then
  AC_MSG_WARN(LFC will be disabled)
  lfc_supported="no"
else
  AC_DEFINE(HAVE_LFC_API_H,,[gLite LFC])
  lfc_supported="yes"
fi
 
AM_CONDITIONAL(HAVE_LFC, test "x$lfc" = xtrue)

dnl
dnl Check how signal SIG_CHLD is treated in threads
dnl
nonposix_signals_in_threads=
LIBS=-lpthread
AC_MSG_CHECKING(for signals in threads)
AC_TRY_RUN(
#include <stdlib.h>
#include <errno.h>
#include <pthread.h>
#include <sys/types.h>
#include <sys/wait.h>
#include <unistd.h>

pid_t pid = -1;
int res = -2;

void* parent_thread(void *arg) {
  pid=fork();
  if(pid == -1) {
    _exit(-1);
  };
  if(pid == 0) {
    sleep(5);
    exit(0);
  };
  sleep(1000);
}

void* waiter_thread(void *arg) {
  int status;
  pid_t p;
  sleep(2);
  p=waitpid(pid,&status,0);
  if(p == -1) {
    if(errno != ECHILD) { res=-1; } else { res=1; };
    _exit(res);
  };
  if(p == 0) {
    res=-1;
    _exit(-1);
  };
  res=0;
}

int main(void) {
  pthread_t parent_thr;
  pthread_t waiter_thr;
  int n;
  if(pthread_create(&parent_thr,NULL,&parent_thread,NULL) != 0) {
    _exit(-1);
  };
  if(pthread_create(&waiter_thr,NULL,&waiter_thread,NULL) != 0) {
    _exit(-1);
  };
  for(n=0;n<30;n++) {
    sleep(1);
    if(res!=-2) break;
  };
  _exit(res);
}
  ,
  AC_MSG_RESULT([quite POSIX]),
  [AC_DEFINE(NONPOSIX_SIGNALS_IN_THREADS,,[Old Linux pthreads])
  AC_MSG_RESULT([not a POSIX])],
  AC_MSG_ERROR([cross-compilation is not supported])
)
AM_CONDITIONAL(NONPOSIX_SIGNALS_IN_THREADS, test "x$nonposix_signals_in_threads" != "x")


dnl
dnl Experimental code
dnl
AC_ARG_ENABLE(experimental,
  [  --enable-experimental              Enable experimental code],  
  [
    case "${enableval}" in
      yes) experimental=true ;;
      no)  experimental=false ;;
      *)   AC_MSG_ERROR(bad value ${enableval} for --enable-experimental) ;;
    esac
  ],
  [ experimental=false ]
)
if test "x$experimental" = "xtrue"; then
  if test "x$gsoap_location" = "x"; then
    AC_MSG_ERROR(Currently there is no experimental code to be built without gSOAP)
  fi
dnl  AC_MSG_NOTICE([Turning on experimental code])
fi
AM_CONDITIONAL(EXPERIMENTAL, test x$experimental = xtrue)
AM_CONDITIONAL(BUILD_LOGGER, test "x$mysql_config" != "x" && test "x$gsoap_location" != "x")
AM_CONDITIONAL(BUILD_HTTPSD, test "x$gsoap_location" != "x")
AM_CONDITIONAL(BUILD_SE, test "x$xml_config" != "x" && test "x$gsoap_location" != "x")
AM_CONDITIONAL(BUILD_SRM, test "x$WSDL2H" != "x")
AM_CONDITIONAL(BUILD_JSDL, test "x$WSDL2H" != "x" && test "x$OLD_GSOAP" = "x")
AM_CONDITIONAL(BUILD_FIREMAN, test "x$WSDL2H" != "x")
AM_CONDITIONAL(BUILD_GUI, test "x$have_qt" != "x" && test "x$experimental" = "xtrue")
AM_CONDITIONAL(BUILD_JOBSSERVICE, test "x$WSDL2H" != "x" && test "x$experimental" = "xtrue")

if test "x$mysql_config" != "x" && test "x$gsoap_location" != "x"; then
   logger_supported="yes"
else
   logger_supported="no"
fi

if test "x$WSDL2H" = "x"; then
  AC_DEFINE(SRM_MISSING,,[Can't build SRM code])
  AC_DEFINE(FIREMAN_MISSING,,[Can't build Fireman code])
  srm_supported="no"
  fireman_supported="no"
else
  srm_supported="yes"
  fireman_supported="yes"
fi

if test "x$WSDL2H" = "x" || test "x$OLD_GSOAP" != "x" ; then
  AC_DEFINE(JSDL_MISSING,,[Can't build JSDL code])
  jsdl_supported="no"
else
  jsdl_supported="yes"
fi

dnl Add ${GLOBUS_LOCATION:-/usr}/lib $GSOAP_LOCATION/$lib to search for system dynamic libraries.
dnl Is used to avoid rpath of the specified paths
  
AC_ARG_ENABLE(rpath-hack,
  [  --disable-rpath-hack               Do not rpath external and internal libraries in libraries/binaries],
  [
    case "${enableval}" in
      yes) rpath_hack=true ;;
      no)  rpath_hack=false ;;
      *)   AC_MSG_ERROR(bad value ${enableval} for --enable-rpath-hack) ;;
    esac
  ],
  [ rpath_hack=true ]
)
if test "x$rpath_hack" = "xtrue"; then
  ARC_WITH_FINAL_PREFIX([
      eval final_libdir="\"${libdir}\""
  ])
  cp -p libtool libtool.orig
  cat libtool.orig \
  | sed "s,\(^sys_lib_dlsearch_path_spec=.*\).$,\1 ${GLOBUS_LOCATION:-/usr}/lib $GSOAP_LOCATION/$lib $final_libdir\"," > libtool
fi

]
)
